%define nginx_user apache
%define nginx_group %{nginx_user}
%define nginx_home /var/lib/nginx
%define nginx_home_tmp %{nginx_home}/tmp
%define nginx_logdir /var/log/nginx
%define nginx_confdir %{_sysconfdir}/nginx
%define nginx_datadir %{_datadir}/nginx
%define nginx_webroot %{nginx_datadir}/html

Summary:	Robust, small and high performance http and reverse proxy server
Name:		nginx
Version:	1.18.0
%define subrel	2
Release:	%mkrel 5
Group:		System/Servers
# BSD License (two clause)
# http://www.freebsd.org/copyright/freebsd-license.html
License:	BSD
URL:		http://nginx.net/
Source0:	http://nginx.org/download/nginx-%{version}.tar.gz
Source1:	http://nginx.org/download/nginx-%{version}.tar.gz.asc
Source3:	%{name}.logrotate
Source4:	%{name}.sysconfig
Source5:	%{name}.service

Source6:	nginx.conf
Source7:	default.conf
Source8:	ssl.conf
Source9:	virtual.conf
Source100:	index.html
Source101:	poweredby.png
Source102:	nginx-logo.png
Source103:	50x.html
Source104:	404.html

#
# Security Patches
# P100 -> ...
#
Patch100:	nginx-CVE-2021-23017.patch
# CVE-2021-3618
Patch101:	ec1071830799.patch
Requires(pre):  webserver-base
BuildRequires:	pkgconfig(geoip)
BuildRequires:	pkgconfig(gdlib)
BuildRequires:	pkgconfig(libnsl)
BuildRequires:	pkgconfig(libxslt)
BuildRequires:	pkgconfig(openssl)
BuildRequires:	pkgconfig(libpcre)
BuildRequires:	pkgconfig(zlib)
BuildRequires:	perl-devel
BuildRequires:	perl(ExtUtils::Embed)
Requires:	pcre
Requires:	openssl
Requires:	webserver-base
Provides:	webserver

%description
Nginx [engine x] is an HTTP(S) server, HTTP(S) reverse proxy and IMAP/POP3
proxy server written by Igor Sysoev.

%prep
%setup -q
%autopatch -p1

%build
%serverbuild
# nginx does not utilize a standard configure script.  It has its own
# and the standard configure options cause the nginx configure script
# to error out.  This is is also the reason for the DESTDIR environment
# variable.  The configure script(s) have been patched (Patch1 and
# Patch2) in order to support installing into a build environment.
export DESTDIR=%{buildroot}
./configure \
    --prefix=%{nginx_datadir} \
    --sbin-path=%{_sbindir}/%{name} \
    --conf-path=%{nginx_confdir}/%{name}.conf \
    --error-log-path=%{nginx_logdir}/error.log \
    --http-log-path=%{nginx_logdir}/access.log \
    --http-client-body-temp-path=%{nginx_home_tmp}/client_body \
    --http-proxy-temp-path=%{nginx_home_tmp}/proxy \
    --http-fastcgi-temp-path=%{nginx_home_tmp}/fastcgi \
    --http-uwsgi-temp-path=%{nginx_home_tmp}/uwsgi \
    --http-scgi-temp-path=%{nginx_home_tmp}/scgi \
    --pid-path=/run/%{name}.pid \
    --lock-path=/run/lock/subsys/%{name} \
    --user=%{nginx_user} \
    --group=%{nginx_group} \
    --with-threads \
    --with-file-aio \
    --with-ipv6 \
    --with-http_ssl_module \
    --with-http_v2_module \
    --with-http_realip_module \
    --with-http_addition_module \
    --with-http_xslt_module \
    --with-http_image_filter_module \
    --with-http_geoip_module \
    --with-http_sub_module \
    --with-http_dav_module \
    --with-http_flv_module \
    --with-http_mp4_module \
    --with-http_gunzip_module \
    --with-http_gzip_static_module \
    --with-http_random_index_module \
    --with-http_secure_link_module \
    --with-http_degradation_module \
    --with-http_stub_status_module \
    --with-http_perl_module \
    --with-mail \
    --with-mail_ssl_module \
    --with-stream \
    --with-stream_ssl_module \
    --with-cc-opt="$CFLAGS $(pcre-config --cflags)" 

%make_build

%install
%make_install INSTALLDIRS=vendor

%{__install} -d -m 755 %{buildroot}%{_sysconfdir}/logrotate.d
%{__install} -m 644 %{SOURCE3} %{buildroot}%{_sysconfdir}/logrotate.d/%{name}

%{__install} -d -m 755 %{buildroot}%{_sysconfdir}/sysconfig
%{__install} -m 644 %{SOURCE4} %{buildroot}%{_sysconfdir}/sysconfig/%{name}

%{__install} -d -m 755 %{buildroot}%{_unitdir}
%{__install} -m 644 %{SOURCE5} %{buildroot}%{_unitdir}

%{__install} -m 644 %{SOURCE6} %{buildroot}%{nginx_confdir}

%{__install} -d -m 0755 %{buildroot}%{nginx_confdir}/conf.d
%{__install} -m 644 %{SOURCE7} %{SOURCE8} %{SOURCE9} \
    %{buildroot}%{nginx_confdir}/conf.d

%{__install} -d -m 0755 %{buildroot}%{nginx_home_tmp}
%{__install} -d -m 0755 %{buildroot}%{nginx_logdir}
%{__install} -d -m 0755 %{buildroot}%{nginx_webroot}

%{__install} -p -m 0644 %{SOURCE100} %{SOURCE101} %{SOURCE102} \
			%{SOURCE103} %{SOURCE104} \
			%{buildroot}%{nginx_webroot}

perl -pi -e 's/_USER_/%{nginx_user}/' %{buildroot}%{nginx_confdir}/nginx.conf

# add current version
perl -pi -e 's/_VERSION_/%{version}/g' %{buildroot}%{nginx_webroot}/index.html

# convert to UTF-8 all files that give warnings.
for textfile in CHANGES; do
    mv $textfile $textfile.old
    iconv --from-code ISO8859-1 --to-code UTF-8 --output $textfile $textfile.old
    rm -f $textfile.old
done

install -d %{buildroot}%{_mandir}/man8
install -m0644 man/*.8 %{buildroot}%{_mandir}/man8/

%post
%_post_service %{name}

%preun
%_preun_service %{name}

%files
%doc LICENSE CHANGES README
%{nginx_datadir}
%{_sbindir}/%{name}
%{_mandir}/man3/%{name}.3pm*
%{_mandir}/man8/*
%{_unitdir}/%{name}.service
%dir %{nginx_confdir}
%dir %{nginx_confdir}/conf.d
%config(noreplace) %{nginx_confdir}/conf.d/*.conf
%config(noreplace) %{nginx_confdir}/win-utf
%config(noreplace) %{nginx_confdir}/%{name}.conf.default
%config(noreplace) %{nginx_confdir}/scgi_params
%config(noreplace) %{nginx_confdir}/scgi_params.default
%config(noreplace) %{nginx_confdir}/fastcgi.conf
%config(noreplace) %{nginx_confdir}/fastcgi.conf.default
%config(noreplace) %{nginx_confdir}/mime.types.default
%config(noreplace) %{nginx_confdir}/fastcgi_params
%config(noreplace) %{nginx_confdir}/fastcgi_params.default
%config(noreplace) %{nginx_confdir}/koi-win
%config(noreplace) %{nginx_confdir}/koi-utf
%config(noreplace) %{nginx_confdir}/%{name}.conf
%config(noreplace) %{nginx_confdir}/mime.types
%config(noreplace) %{nginx_confdir}/uwsgi_params
%config(noreplace) %{nginx_confdir}/uwsgi_params.default
%config(noreplace) %{_sysconfdir}/logrotate.d/%{name}
%config(noreplace) %{_sysconfdir}/sysconfig/%{name}
%{perl_vendorarch}/auto/%{name}
%{perl_vendorarch}/%{name}.pm
%attr(-,%{nginx_user},%{nginx_group}) %dir %{nginx_home}
%attr(-,%{nginx_user},%{nginx_group}) %dir %{nginx_home_tmp}
%attr(-,root,adm) %dir %{nginx_logdir}


%changelog
* Wed Dec 01 2021 neoclust <neoclust> 1.18.0-5.2.mga8
+ Revision: 1760213
- Add P101: Fixes CVE-2021-3618 (mga#29220)
+ luigiwalser <luigiwalser>
- add upstream patch to fix CVE-2021-23017

* Tue Dec 15 2020 tv <tv> 1.18.0-5.mga8
+ Revision: 1657531
- BR pkgconfig(libnsl)

* Fri Oct 30 2020 guillomovitch <guillomovitch> 1.18.0-4.mga8
+ Revision: 1640708
- switch to apache user, as other webservers
- drop obsolete versioned dependency on rpm-helper

* Sat Oct 24 2020 guillomovitch <guillomovitch> 1.18.0-3.mga8
+ Revision: 1639039
- sync systemd unit with fedora, for better consistency with apache

* Wed Jun 17 2020 umeabot <umeabot> 1.18.0-2.mga8
+ Revision: 1594234
- Rebuild for perl 5.32

* Tue Apr 21 2020 kekepower <kekepower> 1.18.0-1.mga8
+ Revision: 1570453
- Update to version 1.18.0

* Tue Apr 14 2020 kekepower <kekepower> 1.17.10-1.mga8
+ Revision: 1567373
- Update to version 1.17.10

* Sun Mar 22 2020 eatdirt <eatdirt> 1.17.9-2.mga8
+ Revision: 1558951
- Add dep to network.target to circumvent early start failure

* Mon Mar 16 2020 tv <tv> 1.17.9-1.mga8
+ Revision: 1556618
- 1.17.9 (hopefully will fix segfaults...)

* Wed Feb 19 2020 umeabot <umeabot> 1.17.8-3.mga8
+ Revision: 1543580
- Mageia 8 Mass Rebuild

* Tue Feb 11 2020 kekepower <kekepower> 1.17.8-2.mga8
+ Revision: 1490394
- Require webserver-base (mga#26183)

* Tue Jan 21 2020 kekepower <kekepower> 1.17.8-1.mga8
+ Revision: 1481959
- Update to version 1.17.8

* Thu Dec 26 2019 kekepower <kekepower> 1.17.7-1.mga8
+ Revision: 1470135
- Update to version 1.17.7

* Sun Oct 27 2019 kekepower <kekepower> 1.17.5-1.mga8
+ Revision: 1456134
- Update to version 1.17.5

* Mon Aug 26 2019 tv <tv> 1.17.3-2.mga8
+ Revision: 1432729
- rebuild with perl-5.30

* Wed Aug 14 2019 kekepower <kekepower> 1.17.3-1.mga8
+ Revision: 1429292
- Update to 1.17.3 to fix CVE-2019-9511, CVE-2019-9513, CVE-2019-9516 (mga#25303)

* Mon Jul 29 2019 kekepower <kekepower> 1.17.2-1.mga8
+ Revision: 1425118
- Update to version 1.17.2

* Tue Apr 23 2019 kekepower <kekepower> 1.16.0-1.mga7
+ Revision: 1395030
- Update to version 1.16.0

* Mon Mar 04 2019 kekepower <kekepower> 1.15.9-1.mga7
+ Revision: 1371552
- Update to version 1.15.9

* Sun Dec 30 2018 kekepower <kekepower> 1.15.8-1.mga7
+ Revision: 1347249
- Update to version 1.15.8

* Wed Dec 05 2018 kekepower <kekepower> 1.15.7-1.mga7
+ Revision: 1338418
- Update to version 1.15.7

* Tue Nov 06 2018 kekepower <kekepower> 1.15.6-1.mga7
+ Revision: 1328692
- Update to version 1.15.6

* Wed Oct 03 2018 kekepower <kekepower> 1.15.5-1.mga7
+ Revision: 1317270
- Update to version 1.15.5

* Thu Sep 27 2018 kekepower <kekepower> 1.15.4-1.mga7
+ Revision: 1308678
- Update to version 1.15.4

* Sat Sep 22 2018 kekepower <kekepower> 1.15.3-1.mga7
+ Revision: 1296453
- Update to version 1.15.3

* Tue Aug 07 2018 guillomovitch <guillomovitch> 1.14.0-2.mga7
+ Revision: 1248764
- rebuild for perl 5.28

* Tue Apr 17 2018 kekepower <kekepower> 1.14.0-1.mga7
+ Revision: 1219698
- Update to latest, stable release 1.14.0

* Mon Apr 09 2018 kekepower <kekepower> 1.12.2-1.mga7
+ Revision: 1216583
- Update to version 1.12.2

* Sun Aug 06 2017 tv <tv> 1.12.1-3.mga7
+ Revision: 1137874
- rebuild for new openssl

* Sat Jul 22 2017 neoclust <neoclust> 1.12.1-2.mga7
+ Revision: 1127655
- Rebuild against new Perl 5.26

* Wed Jul 19 2017 tv <tv> 1.12.1-1.mga7
+ Revision: 1125051
- new release

* Wed Feb 01 2017 luigiwalser <luigiwalser> 1.10.3-1.mga6
+ Revision: 1084450
- 1.10.3

* Wed Nov 30 2016 mrambo3501 <mrambo3501> 1.10.2-2.mga6
+ Revision: 1071347
- change log directory ownership to fix CVE-2016-1247

* Tue Oct 18 2016 luigiwalser <luigiwalser> 1.10.2-1.mga6
+ Revision: 1061962
- 1.10.2

* Tue May 31 2016 luigiwalser <luigiwalser> 1.10.1-1.mga6
+ Revision: 1019630
- 1.10.1 (fixes CVE-2016-4450)

* Thu May 26 2016 luigiwalser <luigiwalser> 1.10.0-2.mga6
+ Revision: 1018738
+ rebuild (emptylog)

* Wed May 25 2016 tv <tv> 1.11.0-1.mga6
+ Revision: 1018246
+ rebuild (emptylog)

* Wed Apr 27 2016 tv <tv> 1.10.0-1.mga6
+ Revision: 1006712
- 1.10.0

* Fri Apr 22 2016 tv <tv> 1.9.15-1.mga6
+ Revision: 1005273
- 1.9.15

* Fri Apr 22 2016 tv <tv> 1.9.14-1.mga6
+ Revision: 1004906
- 1.9.14

* Wed Mar 02 2016 umeabot <umeabot> 1.9.12-2.mga6
+ Revision: 983801
- Rebuild for openssl

* Wed Mar 02 2016 oden <oden> 1.9.12-1.mga6
+ Revision: 983103
- 1.9.12

* Wed Jan 27 2016 luigiwalser <luigiwalser> 1.9.10-1.mga6
+ Revision: 928264
- 1.9.10

* Fri Dec 18 2015 oden <oden> 1.9.9-1.mga6
+ Revision: 911635
- 1.9.9

* Thu Jun 25 2015 tv <tv> 1.6.2-7.mga6
+ Revision: 843435
- rebuild with soname-ified perl

* Tue Jun 23 2015 sander85 <sander85> 1.6.2-6.mga6
+ Revision: 840465
- Rebuild for perl 5.22

* Mon Feb 16 2015 oden <oden> 1.6.2-5.mga5
+ Revision: 815158
- rebuilt for libgd-2.1.1

* Wed Oct 15 2014 umeabot <umeabot> 1.6.2-4.mga5
+ Revision: 749897
- Second Mageia 5 Mass Rebuild

* Thu Oct 09 2014 tv <tv> 1.6.2-3.mga5
+ Revision: 737725
- rebuild for new perl

* Tue Sep 16 2014 umeabot <umeabot> 1.6.2-2.mga5
+ Revision: 682881
- Mageia 5 Mass Rebuild
+ luigiwalser <luigiwalser>
- 1.6.2 (fixes CVE-2014-3616)

* Mon Sep 01 2014 luigiwalser <luigiwalser> 1.6.1-1.mga5
+ Revision: 670758
- 1.6.1 (fixes CVE-2014-3556)

* Tue Jun 03 2014 pterjan <pterjan> 1.6.0-2.mga5
+ Revision: 630783
- Rebuild for perl 5.20

* Fri Apr 25 2014 thatsamguy <thatsamguy> 1.6.0-1.mga5
+ Revision: 617716
- update to new stable branch and release v1.6.0

* Wed Mar 19 2014 thatsamguy <thatsamguy> 1.5.12-1.mga5
+ Revision: 605596
- update to latest release 1.5.12 (fixes CVE-2014-0133)

* Tue Feb 11 2014 thatsamguy <thatsamguy> 1.5.10-1.mga5
+ Revision: 589567
- update to latest mainline release v1.5.10

* Tue Feb 04 2014 tv <tv> 1.4.4-2.mga5
+ Revision: 581925
- rebuild for new perl

* Wed Nov 20 2013 thatsamguy <thatsamguy> 1.4.4-1.mga4
+ Revision: 552017
- new version 1.4.4 to fix security issue (CVE-2013-4547)

* Tue Oct 22 2013 umeabot <umeabot> 1.4.3-4.mga4
+ Revision: 545013
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 thatsamguy <thatsamguy> 1.4.3-3.mga4
+ Revision: 500479
-revert to 1.4.3
-bump rel to 3 for prev logrotate fix
- remove obsolete file
- enable auth_request module
- switch logrotate to use systemd commands
- new version 1.5.6

* Thu Oct 10 2013 thatsamguy <thatsamguy> 1.4.3-2.mga4
+ Revision: 494697
-fixed conf file install location
-fixed log restart during logrotate
-enabled spdy module
-enabled gunzip module
-spec file cleanup

* Wed Oct 09 2013 guillomovitch <guillomovitch> 1.4.3-1.mga4
+ Revision: 494108
- new version 1.4.3

* Wed Aug 28 2013 tv <tv> 1.2.9-5.mga4
+ Revision: 472742
- rebuild for new perl

* Wed May 29 2013 tv <tv> 1.2.9-4.mga4
+ Revision: 430245
- rebuild for new perl

* Tue May 28 2013 luigiwalser <luigiwalser> 1.2.9-3.mga4
+ Revision: 429683
- re-add poweredby.png (used in index.html)

* Tue May 28 2013 oden <oden> 1.2.9-2.mga4
+ Revision: 429295
- rebuilt against libgd.so.3

* Mon May 13 2013 luigiwalser <luigiwalser> 1.2.9-1.mga3
+ Revision: 413086
- 1.2.9 (fixes CVE-2013-2070)

* Wed Mar 20 2013 tv <tv> 1.2.6-3.mga3
+ Revision: 404178
- rebuild for new perl...
+ umeabot <umeabot>
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Fri Jan 04 2013 luigiwalser <luigiwalser> 1.2.6-1.mga3
+ Revision: 338529
- 1.2.6

* Sat Dec 01 2012 fwang <fwang> 1.2.5-2.mga3
+ Revision: 323813
- rebuild for new pcre

* Thu Nov 15 2012 fwang <fwang> 1.2.5-1.mga3
+ Revision: 317995
- new version 1.2.5

* Wed Sep 26 2012 fwang <fwang> 1.2.4-1.mga3
+ Revision: 297827
- new version 1.2.4

* Sat Sep 08 2012 guillomovitch <guillomovitch> 1.2.3-1.mga3
+ Revision: 290421
- new version

* Wed Aug 29 2012 tv <tv> 1.2.2-3.mga3
+ Revision: 285543
- rebuild for new perl

* Thu Aug 09 2012 tv <tv> 1.2.2-2.mga3
+ Revision: 280274
- drop sysv service

* Wed Jul 04 2012 fwang <fwang> 1.2.2-1.mga3
+ Revision: 267695
- new version 1.2.2

* Sat Jun 09 2012 shlomif <shlomif> 1.2.1-1.mga3
+ Revision: 258749
- New version - 1.2.1

* Wed May 30 2012 jquelin <jquelin> 1.2.0-2.mga3
+ Revision: 250255
- rebuild for perl 5.16

* Mon May 28 2012 fwang <fwang> 1.2.0-1.mga3
+ Revision: 247662
- new version 1.2.0

* Sat Apr 28 2012 tmb <tmb> 1.0.15-2.mga2
+ Revision: 233820
- Require rpm-helper >= 0.24.8-1 for systemd support

* Thu Apr 19 2012 fwang <fwang> 1.0.15-1.mga2
+ Revision: 231795
- new version 1.0.15

* Mon Mar 19 2012 guillomovitch <guillomovitch> 1.0.14-2.mga2
+ Revision: 224503
- drop last mandriva references (#3815)

* Mon Mar 19 2012 guillomovitch <guillomovitch> 1.0.14-1.mga2
+ Revision: 224303
+ rebuild (emptylog)

* Thu Mar 15 2012 guillomovitch <guillomovitch> 1.0.10-2.mga2
+ Revision: 223512
- sync configuration files with fedora package
- drop useless apache dependency
- spec cleanup
- systemd support

* Mon Jan 09 2012 fwang <fwang> 1.0.10-1.mga2
+ Revision: 193691
- new version 1.0.10

* Fri Nov 04 2011 fwang <fwang> 1.0.9-1.mga2
+ Revision: 162665
- new version 1.0.9

* Thu Oct 20 2011 tv <tv> 1.0.8-2.mga2
+ Revision: 156981
- rebuild for new perl

* Sun Oct 02 2011 fwang <fwang> 1.0.8-1.mga2
+ Revision: 150974
- new version 1.0.8

* Sun Sep 18 2011 dmorgan <dmorgan> 1.0.6-2.mga2
+ Revision: 144695
- Change apache-conf require

* Wed Aug 31 2011 fwang <fwang> 1.0.6-1.mga2
+ Revision: 136890
- new version 1.0.6

* Wed Jul 20 2011 fwang <fwang> 1.0.5-1.mga2
+ Revision: 127063
- rediff conf patch
- add signature
- new version 1.0.5

* Thu Jun 16 2011 tv <tv> 1.0.4-1.mga2
+ Revision: 108442
- new relase
- vendor is mga not mdv
- s/mdv/mga/

* Sat Jun 11 2011 jquelin <jquelin> 1.0.0-2.mga2
+ Revision: 103442
- perl 5.14

* Wed Apr 13 2011 tv <tv> 1.0.0-1.mga1
+ Revision: 84509
- new release

* Sun Feb 20 2011 dmorgan <dmorgan> 0.9.3-1.mga1
+ Revision: 54507
- imported package nginx


* Sat Jan 01 2011 Oden Eriksson <oeriksson@mandriva.com> 0.9.3-1mdv2011.0
+ Revision: 627093
- 0.9.3

* Tue Nov 02 2010 Rémy Clouard <shikamaru@mandriva.org> 0.8.53-2mdv2011.0
+ Revision: 592564
- make nginx provide webserver

* Tue Oct 19 2010 Funda Wang <fwang@mandriva.org> 0.8.53-1mdv2011.0
+ Revision: 586696
- new version 0.8.53

* Mon Oct 04 2010 Funda Wang <fwang@mandriva.org> 0.8.52-1mdv2011.0
+ Revision: 582791
- update to new version 0.8.52

* Mon Aug 09 2010 Funda Wang <fwang@mandriva.org> 0.8.49-1mdv2011.0
+ Revision: 567990
- update to new version 0.8.49

* Wed Aug 04 2010 Funda Wang <fwang@mandriva.org> 0.8.48-1mdv2011.0
+ Revision: 565647
- update to new version 0.8.48

* Sun Aug 01 2010 Funda Wang <fwang@mandriva.org> 0.8.47-1mdv2011.0
+ Revision: 564290
- update to new version 0.8.47

* Tue Jul 20 2010 Jérôme Quelin <jquelin@mandriva.org> 0.8.46-2mdv2011.0
+ Revision: 555663
- rebuild

* Mon Jul 19 2010 Funda Wang <fwang@mandriva.org> 0.8.46-1mdv2011.0
+ Revision: 554964
- new version 0.8.46

* Tue Jun 15 2010 Oden Eriksson <oeriksson@mandriva.com> 0.8.41-1mdv2010.1
+ Revision: 548065
- 0.8.41

* Thu May 06 2010 Oden Eriksson <oeriksson@mandriva.com> 0.8.36-1mdv2010.1
+ Revision: 542875
- 0.8.36

* Wed Apr 14 2010 Oden Eriksson <oeriksson@mandriva.com> 0.8.35-1mdv2010.1
+ Revision: 534664
- 0.8.35
- use the %%serverbuild macro

* Wed Apr 07 2010 Funda Wang <fwang@mandriva.org> 0.8.34-3mdv2010.1
+ Revision: 532516
- rebuild

* Mon Mar 29 2010 Michael Scherer <misc@mandriva.org> 0.8.34-2mdv2010.1
+ Revision: 528833
- remove patch0, no longer useful ( as nginx compile fine with -Werror
  and -D_FORTIFY_SOURCE=2 )

* Thu Mar 04 2010 Funda Wang <fwang@mandriva.org> 0.8.34-1mdv2010.1
+ Revision: 514055
- new version 0.8.34

* Fri Feb 26 2010 Oden Eriksson <oeriksson@mandriva.com> 0.8.33-2mdv2010.1
+ Revision: 511596
- rebuilt against openssl-0.9.8m

* Wed Feb 17 2010 Oden Eriksson <oeriksson@mandriva.com> 0.8.33-1mdv2010.1
+ Revision: 506976
- 0.8.33

* Thu Jan 14 2010 Michael Scherer <misc@mandriva.org> 0.8.31-2mdv2010.1
+ Revision: 491109
- enable ipv6, for point spec104 of 2010.1 ( ipv6 support )

  + Oden Eriksson <oeriksson@mandriva.com>
    - fix deps (shikamaru)

* Wed Jan 06 2010 Frederik Himpe <fhimpe@mandriva.org> 0.8.31-1mdv2010.1
+ Revision: 486834
- update to new version 0.8.31

* Sun Dec 20 2009 Oden Eriksson <oeriksson@mandriva.com> 0.8.30-1mdv2010.1
+ Revision: 480481
- 0.8.30

* Sat Dec 12 2009 Frederik Himpe <fhimpe@mandriva.org> 0.8.29-1mdv2010.1
+ Revision: 477775
- update to new version 0.8.29

* Wed Nov 25 2009 Funda Wang <fwang@mandriva.org> 0.8.28-1mdv2010.1
+ Revision: 469934
- update to new version 0.8.28

* Tue Nov 17 2009 Frederik Himpe <fhimpe@mandriva.org> 0.8.27-1mdv2010.1
+ Revision: 467003
- update to new version 0.8.27

* Sat Nov 07 2009 Frederik Himpe <fhimpe@mandriva.org> 0.8.22-1mdv2010.1
+ Revision: 462619
- update to new version 0.8.22

  + Thomas Backlund <tmb@mandriva.org>
    - fix typo in initscript

* Mon Sep 28 2009 Frederik Himpe <fhimpe@mandriva.org> 0.8.17-1mdv2010.0
+ Revision: 450653
- update to new version 0.8.17

* Mon Sep 14 2009 Frederik Himpe <fhimpe@mandriva.org> 0.8.15-1mdv2010.0
+ Revision: 440749
- update to new version 0.8.15

* Sat Aug 29 2009 Frederik Himpe <fhimpe@mandriva.org> 0.8.11-1mdv2010.0
+ Revision: 422223
- update to new version 0.8.11

* Wed Aug 12 2009 Frederik Himpe <fhimpe@mandriva.org> 0.8.8-1mdv2010.0
+ Revision: 415678
- update to new version 0.8.8

* Sun Jun 28 2009 Oden Eriksson <oeriksson@mandriva.com> 0.8.4-1mdv2010.0
+ Revision: 390248
- import nginx


* Sun Jun 28 2009 Oden Eriksson <oeriksson@mandriva.com> 0.8.4-1
- initial Mandriva package (fedora import)

* Sun May 17 2009 Jeremy Hinegardner <jeremy at hinegardner dot org> - 0.6.36-2
- init script updates from Gena Makhomed
- remove nginx-upstream-fair

* Sat Apr 11 2009 Jeremy Hinegardner <jeremy at hinegardner dot org> - 0.6.36-1
-  update to 0.6.36

* Wed Feb 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.6.35-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Thu Feb 19 2009 Jeremy Hinegardner <jeremy at hinegardner dot org> - 0.6.35-2
- rebuild

* Thu Feb 19 2009 Jeremy Hinegardner <jeremy at hinegardner dot org> - 0.6.35-1
- update to 0.6.35

* Sat Jan 17 2009 Tomas Mraz <tmraz@redhat.com> - 0.6.34-2
- rebuild with new openssl

* Tue Dec 30 2008 Jeremy Hinegardner <jeremy at hinegardner dot org> - 0.6.34-1
- update to 0.6.34

* Thu Dec  4 2008 Michael Schwendt <mschwendt@fedoraproject.org> - 0.6.33-2
- Fix inclusion of /usr/share/nginx tree => no unowned directories.

* Sun Nov 23 2008 Jeremy Hinegardner <jeremy at hinegardner dot org> - 0.6.33-1
- update to 0.6.33

* Tue Jul 22 2008 Jeremy Hinegardner <jeremy at hinegardner dot org> - 0.6.32-1
- update to 0.6.32
- nginx now supports DESTDIR so removed the patches that enabled it 

* Mon May 26 2008 Jeremy Hinegardner <jeremy at hinegardner dot org> - 0.6.31-3
- init script fixes
- resolve 'listen 80 default' [#447873]

* Mon May 12 2008 Jeremy Hinegardner <jeremy at hinegardner dot org> - 0.6.31-2
- update to 0.6.31

* Sun May 11 2008 Jeremy Hinegardner <jeremy at hinegardner dot org> - 0.6.30-2
- upate to new upstream stable branch 0.6
- added 3rd party module nginx-upstream-fair
- added default webpages

* Sun Apr 20 2008 Jeremy Hinegardner <jeremy at hinegardner dot org> - 0.5.35-2
- update init script to match recommended guidelines
- add /etc/nginx/conf.d support [#443280]
- use /etc/sysconfig/nginx to determine nginx.conf [#442708]

* Tue Mar 18 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 0.5.35-3
- add Requires for versioned perl (libperl.so)
- drop silly file Requires

* Tue Feb 19 2008 Fedora Release Engineering <rel-eng@fedoraproject.org> - 0.5.35-2
- Autorebuild for GCC 4.3

* Sat Jan 19 2008 Jeremy Hinegardner <jeremy at hinegardner dot org> - 0.5.35-1
- update to 0.5.35

* Sat Dec 15 2007 Jeremy Hinegardner <jeremy at hinegardner dot org> - 0.5.34-1
- update to 0.5.34

* Wed Dec 05 2007 Release Engineering <rel-eng at fedoraproject dot org> - 0.5.33-2
 - Rebuild for deps

* Sun Nov 11 2007 Jeremy Hinegardner <jeremy@hinegardner.org> - 0.5.33-1
- update to 0.5.33

* Mon Sep 24 2007 Jeremy Hinegardner <jeremy@hinegardner.org> - 0.5.32-1
- updated to 0.5.32
- fixed rpmlint UTF-8 complaints.

* Sat Aug 18 2007 Jeremy Hinegardner <jeremy@hinegardner.org> - 0.5.31-2
- added --with-http_stub_status_module build option.
- added --with-http_sub_module build option.
- added use of pcre-config --cflags

* Fri Aug 17 2007 Jeremy Hinegardner <jeremy@hinegardner.org> - 0.5.31-1
- Update to 0.5.31
- specify license is BSD

* Sat Aug 11 2007 Jeremy Hinegardner <jeremy@hinegardner.org> - 0.5.30-2
- Add BuildRequires: perl-devel - fixing rawhide build

* Mon Jul 30 2007 Jeremy Hinegardner <jeremy@hinegardner.org> - 0.5.30-1
- Update to 0.5.30

* Tue Jul 24 2007 Jeremy Hinegardner <jeremy@hinegardner.org> - 0.5.29-1
- Update to 0.5.29

* Wed Jul 18 2007 Jeremy Hinegardner <jeremy@hinegardner.org> - 0.5.28-1
- Update to 0.5.28

* Mon Jul 09 2007 Jeremy Hinegardner <jeremy@hinegardner.org> - 0.5.27-1
- Update to 0.5.27

* Mon Jun 18 2007 Jeremy Hinegardner <jeremy@hinegardner.org> - 0.5.26-1
- Update to 0.5.26

* Sat Apr 28 2007 Jeremy Hinegardner <jeremy@hinegardner.org> - 0.5.19-1
- Update to 0.5.19

* Mon Apr 02 2007 Jeremy Hinegardner <jeremy@hinegardner.org> - 0.5.17-1
- Update to 0.5.17

* Mon Mar 26 2007 Jeremy Hinegardner <jeremy@hinegardner.org> - 0.5.16-1
- Update to 0.5.16
- add ownership of /usr/share/nginx/html (#233950)

* Fri Mar 23 2007 Jeremy Hinegardner <jeremy@hinegardner.org> - 0.5.15-3
- fixed package review bugs (#235222) given by ruben@rubenkerkhof.com

* Thu Mar 22 2007 Jeremy Hinegardner <jeremy@hinegardner.org> - 0.5.15-2
- fixed package review bugs (#233522) given by kevin@tummy.com

* Thu Mar 22 2007 Jeremy Hinegardner <jeremy@hinegardner.org> - 0.5.15-1
- create patches to assist with building for Fedora
- initial packaging for Fedora
